==> freecad_0.17%2Bdfsg1.orig.tar.gz: FreeCAD-0.17/src/Mod/Points/Gui/Resources/translations/Points_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de" sourcelanguage="en">
  <context>
    <name>CmdPointsConvert</name>
    <message>
      <location filename="../../Command.cpp" line="+187"/>
      <source>Points</source>
      <translation>Punkte</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Convert to points...</source>
      <translation>Zu Punkten konvertieren...</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+2"/>
      <source>Convert to points</source>
      <translation>Zu Punkten konvertieren</translation>
    </message>
  </context>
  <context>
    <name>CmdPointsExport</name>
    <message>
      <location line="-80"/>
      <source>Points</source>
      <translation>Punkte</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Export points...</source>
      <translation>Punkte exportieren...</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+2"/>
      <source>Exports a point cloud</source>
      <translation>Exportiert eine Punktwolke</translation>
    </message>
  </context>
  <context>
    <name>CmdPointsImport</name>
    <message>
      <location line="-51"/>
      <source>Points</source>
      <translation>Punkte</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Import points...</source>
      <translation>Punkte importieren...</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+2"/>
      <source>Imports a point cloud</source>
      <translation>Importiert eine Punktwolke</translation>
    </message>
  </context>
  <context>
    <name>CmdPointsMerge</name>
    <message>
      <location line="+245"/>
      <source>Points</source>
      <translation>Punkte</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Merge point clouds</source>
      <translation>Zusammenführen von Punktwolken</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+2"/>
      <source>Merge several point clouds into one</source>
      <translation>Zusammenführen von mehreren Punktwolken in eine</translation>
    </message>
  </context>
  <context>
    <name>CmdPointsPolyCut</name>
    <message>
      <location line="-49"/>
      <source>Points</source>
      <translation>Punkte</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Cut point cloud</source>
      <translation>Punktwolke schneiden</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+2"/>
      <source>Cuts a point cloud with a picked polygon</source>
      <translation>Schneiden einer Punktwolke mit einem gewählten Polygon</translation>
    </message>
  </context>
  <context>
    <name>CmdPointsTransform</name>
    <message>
      <location line="-122"/>
      <source>Points</source>
      <translation>Punkte</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Transform Points</source>
      <translation>Punkte transformieren</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+2"/>
      <source>Test to transform a point cloud</source>
      <translation>Test zur Transformation einer Punktwolke</translation>
    </message>
  </context>
  <context>
    <name>PointsGui::DlgPointsRead</name>
    <message>
      <location filename="../../DlgPointsRead.ui" line="+14"/>
      <source>ASCII points import</source>
      <translation>ASCII-Punkte-Import</translation>
    </message>
    <message>
      <location line="+20"/>
      <source>Template:</source>
      <translation>Vorlage:</translation>
    </message>
    <message>
      <location line="+12"/>
      <source>Special lines</source>
      <translation>Spezielle Zeilen</translation>
    </message>
    <message>
      <location line="+42"/>
      <source>First line:</source>
      <translation>Erste Zeile:</translation>
    </message>
    <message>
      <location line="+12"/>
      <source>Ignore</source>
      <translation>Ignorieren</translation>
    </message>
    <message>
      <location line="-21"/>
      <source>Cluster by lines starting with:</source>
      <translation>Cluster von Zeilen beginnend mit:</translation>
    </message>
    <message>
      <location line="-7"/>
      <source>Ignore lines starting with:</source>
      <translation>Ignoriere Zeilen beginnend mit:</translation>
    </message>
    <message>
      <location line="+54"/>
      <source>Point format</source>
      <translation>Punkte-Format</translation>
    </message>
    <message>
      <location line="+78"/>
      <source>Number separator:</source>
      <translation>Zahlentrenner:</translation>
    </message>
    <message>
      <location line="+98"/>
      <source>Points format:</source>
      <translation>Punkte-Format:</translation>
    </message>
    <message>
      <location line="-91"/>
      <location line="+7"/>
      <location line="+7"/>
      <source>Next block:</source>
      <translation>Nächster Block:</translation>
    </message>
    <message>
      <location line="+40"/>
      <source>,</source>
      <translation>,</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>;</source>
      <translation>;</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>\t</source>
      <translation>\t</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>\w</source>
      <translation>\w</translation>
    </message>
    <message>
      <location line="+9"/>
      <source>X,Y,Z</source>
      <translation>X, Y, Z</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>X,Y</source>
      <translation>X, Y</translation>
    </message>
    <message>
      <location line="-147"/>
      <location line="+29"/>
      <location line="+57"/>
      <source>none</source>
      <translation>keiner</translation>
    </message>
    <message>
      <location line="-81"/>
      <location line="+29"/>
      <location line="+57"/>
      <source>I,J,K (normal vector)</source>
      <translation>I, J, K (Normalenvektor)</translation>
    </message>
    <message>
      <location line="-81"/>
      <location line="+29"/>
      <location line="+57"/>
      <source>I,K (normal vector 2D)</source>
      <translation>I, K (Normalenvektor 2D)</translation>
    </message>
    <message>
      <location line="-81"/>
      <location line="+29"/>
      <location line="+57"/>
      <source>R,G,B (color)</source>
      <translation>R,G,B (Farbe)</translation>
    </message>
    <message>
      <location line="-81"/>
      <location line="+29"/>
      <location line="+57"/>
      <source>I (Gray value)</source>
      <translation>I (Grauwert)</translation>
    </message>
    <message>
      <location line="+61"/>
      <source>Preview</source>
      <translation>Vorschau</translation>
    </message>
    <message>
      <location line="+34"/>
      <source>100</source>
      <translation>100</translation>
    </message>
    <message>
      <location line="-238"/>
      <source>Number of points</source>
      <translation>Anzahl der Punkte</translation>
    </message>
    <message>
      <location line="+231"/>
      <source>Number of previewed lines:</source>
      <translation>Anzahl der angezeigten Zeilen:</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <source>Ascii Points (*.asc);;All Files (*.*)</source>
      <translation>ASCII-Punkte (.asc); Alle Dateien (*.*)</translation>
    </message>
    <message>
      <source>Ascii Points</source>
      <translation>ASCII-Punkte</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="-76"/>
      <location line="+50"/>
      <source>All Files</source>
      <translation>Alle Dateien</translation>
    </message>
    <message>
      <location line="-50"/>
      <location line="+50"/>
      <source>Point formats</source>
      <translation>Punkt-Formate</translation>
    </message>
    <message>
      <location line="+71"/>
      <source>Distance</source>
      <translation>Abstand</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Enter maximum distance:</source>
      <translation>Eingabe der maximalen Entfernung:</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="+37"/>
      <source>Points tools</source>
      <translation>Punktwerkzeuge</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>&amp;Points</source>
      <translation>&amp;Punkte</translation>
    </message>
  </context>
</TS>

==> freecad_0.18~pre1%2Bdfsg1.orig.tar.gz: FreeCAD-0.18_pre/src/Mod/Points/Gui/Resources/translations/Points_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de" sourcelanguage="en">
  <context>
    <name>CmdPointsConvert</name>
    <message>
      <location filename="../../Command.cpp" line="+188"/>
      <source>Points</source>
      <translation>Punkte</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Convert to points...</source>
      <translation>In Punkte konvertieren...</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+2"/>
      <source>Convert to points</source>
      <translation>In Punkte konvertieren</translation>
    </message>
  </context>
  <context>
    <name>CmdPointsExport</name>
    <message>
      <location line="-80"/>
      <source>Points</source>
      <translation>Punkte</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Export points...</source>
      <translation>Punkte exportieren...</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+2"/>
      <source>Exports a point cloud</source>
      <translation>Exportiert eine Punktwolke</translation>
    </message>
  </context>
  <context>
    <name>CmdPointsImport</name>
    <message>
      <location line="-51"/>
      <source>Points</source>
      <translation>Punkte</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Import points...</source>
      <translation>Punkte importieren...</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+2"/>
      <source>Imports a point cloud</source>
      <translation>Importiert eine Punktwolke</translation>
    </message>
  </context>
  <context>
    <name>CmdPointsMerge</name>
    <message>
      <location line="+249"/>
      <source>Points</source>
      <translation>Punkte</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Merge point clouds</source>
      <translation>Punktwolken zusammenführen</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+2"/>
      <source>Merge several point clouds into one</source>
      <translation>Mehrere Punktwolken in eine zusammenführen</translation>
    </message>
  </context>
  <context>
    <name>CmdPointsPolyCut</name>
    <message>
      <location line="-49"/>
      <source>Points</source>
      <translation>Punkte</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Cut point cloud</source>
      <translation>Punktwolke schneiden</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+2"/>
      <source>Cuts a point cloud with a picked polygon</source>
      <translation>Schneiden einer Punktwolke mit einem gewählten Polygon</translation>
    </message>
  </context>
  <context>
    <name>CmdPointsTransform</name>
    <message>
      <location line="-126"/>
      <source>Points</source>
      <translation>Punkte</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Transform Points</source>
      <translation>Punkte transformieren</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+2"/>
      <source>Test to transform a point cloud</source>
      <translation>Test zur Transformation einer Punktwolke</translation>
    </message>
  </context>
  <context>
    <name>PointsGui::DlgPointsRead</name>
    <message>
      <location filename="../../DlgPointsRead.ui" line="+14"/>
      <source>ASCII points import</source>
      <translation>ASCII-Punkte-Import</translation>
    </message>
    <message>
      <location line="+20"/>
      <source>Template:</source>
      <translation>Vorlage:</translation>
    </message>
    <message>
      <location line="+12"/>
      <source>Special lines</source>
      <translation>Spezielle Zeilen</translation>
    </message>
    <message>
      <location line="+42"/>
      <source>First line:</source>
      <translation>Erste Zeile:</translation>
    </message>
    <message>
      <location line="+12"/>
      <source>Ignore</source>
      <translation>Ignorieren</translation>
    </message>
    <message>
      <location line="-21"/>
      <source>Cluster by lines starting with:</source>
      <translation>Cluster von Zeilen beginnend mit:</translation>
    </message>
    <message>
      <location line="-7"/>
      <source>Ignore lines starting with:</source>
      <translation>Ignoriere Zeilen beginnend mit:</translation>
    </message>
    <message>
      <location line="+54"/>
      <source>Point format</source>
      <translation>Punkte-Format</translation>
    </message>
    <message>
      <location line="+78"/>
      <source>Number separator:</source>
      <translation>Zahlentrenner:</translation>
    </message>
    <message>
      <location line="+98"/>
      <source>Points format:</source>
      <translation>Punkte-Format:</translation>
    </message>
    <message>
      <location line="-91"/>
      <location line="+7"/>
      <location line="+7"/>
      <source>Next block:</source>
      <translation>Nächster Block:</translation>
    </message>
    <message>
      <location line="+40"/>
      <source>,</source>
      <translation>,</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>;</source>
      <translation>;</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>\t</source>
      <translation>\t</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>\w</source>
      <translation>\w</translation>
    </message>
    <message>
      <location line="+9"/>
      <source>X,Y,Z</source>
      <translation>X, Y, Z</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>X,Y</source>
      <translation>X, Y</translation>
    </message>
    <message>
      <location line="-147"/>
      <location line="+29"/>
      <location line="+57"/>
      <source>none</source>
      <translation>keiner</translation>
    </message>
    <message>
      <location line="-81"/>
      <location line="+29"/>
      <location line="+57"/>
      <source>I,J,K (normal vector)</source>
      <translation>I, J, K (Normalenvektor)</translation>
    </message>
    <message>
      <location line="-81"/>
      <location line="+29"/>
      <location line="+57"/>
      <source>I,K (normal vector 2D)</source>
      <translation>I, K (Normalenvektor 2D)</translation>
    </message>
    <message>
      <location line="-81"/>
      <location line="+29"/>
      <location line="+57"/>
      <source>R,G,B (color)</source>
      <translation>R,G,B (Farbe)</translation>
    </message>
    <message>
      <location line="-81"/>
      <location line="+29"/>
      <location line="+57"/>
      <source>I (Gray value)</source>
      <translation>I (Grauwert)</translation>
    </message>
    <message>
      <location line="+61"/>
      <source>Preview</source>
      <translation>Vorschau</translation>
    </message>
    <message>
      <location line="+34"/>
      <source>100</source>
      <translation>100</translation>
    </message>
    <message>
      <location line="-238"/>
      <source>Number of points</source>
      <translation>Anzahl der Punkte</translation>
    </message>
    <message>
      <location line="+231"/>
      <source>Number of previewed lines:</source>
      <translation>Anzahl der angezeigten Zeilen:</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <source>Ascii Points (*.asc);;All Files (*.*)</source>
      <translation>ASCII-Punkte (.asc); Alle Dateien (*.*)</translation>
    </message>
    <message>
      <source>Ascii Points</source>
      <translation>ASCII-Punkte</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="-76"/>
      <location line="+50"/>
      <source>All Files</source>
      <translation>Alle Dateien</translation>
    </message>
    <message>
      <location line="-50"/>
      <location line="+50"/>
      <source>Point formats</source>
      <translation>Punkt-Formate</translation>
    </message>
    <message>
      <location line="+71"/>
      <source>Distance</source>
      <translation>Abstand</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Enter maximum distance:</source>
      <translation>Maximale Entfernung eingeben:</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="+37"/>
      <source>Points tools</source>
      <translation>Punktwerkzeuge</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>&amp;Points</source>
      <translation>&amp;Punkte</translation>
    </message>
  </context>
</TS>
